//
//  ViewController.swift
//  PickerView
//
//  Created by swift on 2020/1/3.
//  Copyright © 2020 kydqitb. All rights reserved.
//

import UIKit

class ViewController: UIViewController, UIPickerViewDelegate, UIPickerViewDataSource {
    
    var pickerView: UIPickerView!
    var label: UILabel!
    
    //保存全部数据
    var pickerData: [String: [String]] = [
        "北京":["东城区","西城区","海淀区","朝阳区","丰台区","通州区"],
        "上海":["长宁区","闸北区","闵行区","浦东新区","杨浦区","黄浦区"],
        "天津":["和平区","河西区","南开区","河东区","红桥区","东丽区"]
    ]
    //省份名数据
    var pickerProvincesData : [String] = ["北京", "上海", "天津"] //第一级数据
    var pickerCitiesData: [String] = ["东城区","西城区","海淀区","朝阳区","丰台区","通州区"] //第二级数据

    override func viewDidLoad() {
        super.viewDidLoad()
        // Do any additional setup after loading the view.
        
        addTitleLabel()
        
        addPickerView()
        
        addOtherEvent()

    }
    
    func addTitleLabel() {
        let title = UILabel(frame: CGRect(x: 0, y: 40, width: self.view.frame.width, height: 40))
        title.textAlignment = .center
        title.font = UIFont.systemFont(ofSize: 30)
        title.text = "UIPickerView基础使用"
        self.view.addSubview(title)
    }
    
    func addPickerView() {
        // 选择器
        self.pickerView = UIPickerView()
        //因为该Controller中实现了UIPickerViewDataSource接口所以将dataSource设置成自己
        self.pickerView.dataSource = self
        //将delegate设置成自己
        self.pickerView.delegate = self
        //设置PickerView默认值,inComponent索引为0是选择pickerProvincesData数据，row为1是选择pickerProvincesData数据的索引为1的内容
        self.pickerView.selectRow(1, inComponent: 0, animated: true)
        //inComponent索引为1是选择pickerCitiesData数据，row为2是选择pickerCitiesData数据的索引为2的内容
        self.pickerView.selectRow(2, inComponent: 1, animated: true)
        
        
        self.view.addSubview(self.pickerView)
        addAutoLayout(obj: self.pickerView)
        
        //刷新所有数据
        //        self.pickerView.reloadAllComponents()
    }
    
    func addOtherEvent() {
        // 添加显示
        self.label = UILabel(frame: CGRect(x:50 , y: 300, width: view.frame.width - 100, height: 40))
        self.label.layer.borderWidth = 2
        self.label.layer.borderColor = UIColor.red.cgColor
        self.label.textColor = UIColor.green
        self.label.text = "显示选择内容"
        self.label.textAlignment = .center
        self.view.addSubview(self.label)
        
        // 确认选择内容，添加button
        let button = UIButton(type: UIButton.ButtonType.system)
        button.setTitle("确认选择", for: UIControl.State.normal)
        button.frame = CGRect(x: 50, y: 350, width: view.frame.width - 100, height: 50)
        //addTarget,第一个参数是事件处理者,第二个参数是选择器类型,它指向事件处理方法,第三个参数是事件.
        button.addTarget(self, action: #selector(clickButton(sender:)), for: UIControl.Event.touchUpInside)
        self.view.addSubview(button)
    }
    
    
    
    //MARK: - 执行UIPickViewDataSource协议
    //设置选择框的总列数,继承于UIPickViewDataSource协议
    func numberOfComponents(in pickerView: UIPickerView) -> Int {
        print("numberOfComponents")
        return 2
    }
    
    //设置选择框的总行数,继承于UIPickViewDataSource协议
    func pickerView(_ pickerView: UIPickerView, numberOfRowsInComponent component: Int) -> Int {
        print("pickerView:numberOfRowsInComponent:")
        //总行数设置为数据源的总长度。component :为0 表示第一列，1 表示第二列
        //根据不同的数据源设置不同的个数
        if(component == 0) {
            return self.pickerProvincesData.count
        }else {
            return self.pickerCitiesData.count
        }
    }
    
    //MARK: - 执行UIPickViewDelegate协议
    // 设置选项框各选项的内容
    func pickerView(_ pickerView: UIPickerView, titleForRow row: Int, forComponent component: Int) -> String?{
        print("pickerView:titleForRow:forComponent:")
        if(component == 0) { //选择第一级数据
            // 记录用户选择的值
            let selectedProvince = self.pickerProvincesData[row] as String
            // 根据第一列选择的值，更新第二列数据
            self.pickerCitiesData = self.pickerData[selectedProvince]!
            
            return self.pickerProvincesData[row]
        }else {//选择第二级数据
            return self.pickerCitiesData[row]
        }
    }
    
    // 选择pickerView的某个拨轮中的某行时调用
    func pickerView(_ pickerView: UIPickerView, didSelectRow row: Int, inComponent component: Int) {
        print("pickerView:didSelectRow:inComponent:")
        if(component == 0){
            //刷新第二列的数据源
            self.pickerView.reloadComponent(1)
            //刷新数据源后将第二组数据转到下标为0,并且开启动画效果
            self.pickerView.selectRow(0, inComponent: 1, animated: true)
        }
    }
    
    // 设置每行选项的高度
    func pickerView(_ pickerView: UIPickerView, rowHeightForComponent component: Int) -> CGFloat {
        return 45.0
    }
    
    //按钮的触发事件
    @objc func clickButton(sender: UIButton) {
        //第一列索引
        let index1 = self.pickerView.selectedRow(inComponent: 0)
        //第二列索引
        let index2 = self.pickerView.selectedRow(inComponent: 1)
        let provinces = self.pickerProvincesData[index1]
        let cities = self.pickerCitiesData[index2]

        let title = String(format:"城市：%@ , 区： %@" , provinces , cities)
        self.label.text = title
    }
    
    //AutoLayout 自动布局
    func addAutoLayout(obj: UIPickerView) {
    //除了AutoLayout，AutoresizingMask也是一种布局方式。当我们用AutoLayout代码添加视图时默认情况下，translatesAutoresizingMaskIntoConstraints ＝ true , 此时视图的AutoresizingMask会被转换成对应效果的约束。这样很可能就会和我们手动添加的其它约束有冲突。此属性设置成false时，AutoresizingMask就不会变成约束。也就是说当前视图的 AutoresizingMask失效了。 避免布局冲突，把此设置为false
        obj.translatesAutoresizingMaskIntoConstraints = false
        
        //        自动布局构造函数
        //        NSLayoutConstraint(item: 视图,
        //                           attribute: 约束属性,
        //                           relatedBy: 约束关系,
        //                           toItem: 参照视图,
        //                           attribute: 参照属性,
        //                           multiplier: 乘积,
        //                           constant: 约束数值)
        //设置label控件的左边到self.view的左边距离为50pt
        let objLeft:NSLayoutConstraint = NSLayoutConstraint(item: obj, attribute: NSLayoutConstraint.Attribute.left, relatedBy: NSLayoutConstraint.Relation.equal, toItem: self.view, attribute: NSLayoutConstraint.Attribute.left, multiplier: 1.0, constant: 50)
        obj.superview!.addConstraint(objLeft)
        
        //设置label控件的顶部到self.view的顶部距离为100pt
        let objTop:NSLayoutConstraint = NSLayoutConstraint(item: obj, attribute: NSLayoutConstraint.Attribute.top, relatedBy: NSLayoutConstraint.Relation.equal, toItem: self.view, attribute: NSLayoutConstraint.Attribute.top, multiplier: 1.0, constant: 100)
        obj.superview!.addConstraint(objTop)
        
        //设置label控件的右边到self.view的右边距离为50pt
        let objRight:NSLayoutConstraint = NSLayoutConstraint(item: obj, attribute: NSLayoutConstraint.Attribute.right, relatedBy: NSLayoutConstraint.Relation.equal, toItem: self.view, attribute: NSLayoutConstraint.Attribute.right, multiplier: 1.0, constant: -50)
        obj.superview!.addConstraint(objRight)
        
        //设置label控件的高度为200pt
        let objHeight:NSLayoutConstraint = NSLayoutConstraint(item: obj, attribute: NSLayoutConstraint.Attribute.height, relatedBy: NSLayoutConstraint.Relation.equal, toItem: nil, attribute:NSLayoutConstraint.Attribute.notAnAttribute, multiplier: 1.0, constant: 200)
        obj.superview!.addConstraint(objHeight)
    }


}

